Subject: [SRU][F][PATCH] s390/boot: add secure boot trailer
To: frank.heimes@canonical.com
Cc: frank.heimes@canonical.com

From: Peter Oberparleiter <oberpar@linux.ibm.com>

BugLink: https://bugs.launchpad.net/bugs/1996071

This patch enhances the kernel image adding a trailer as required for
secure boot by future firmware versions.

Cc: <stable@vger.kernel.org> # 5.2+
Signed-off-by: Peter Oberparleiter <oberpar@linux.ibm.com>
Reviewed-by: Sven Schnelle <svens@linux.ibm.com>
Signed-off-by: Vasily Gorbik <gor@linux.ibm.com>
(backported from commit aa127a069ef312aca02b730d5137e1778d0c3ba7)
[Frank Heimes: Backport needed because file 'vmlinux.lds.S' is at a different
 location: 'arch/s390/boot/compressed/' instead of 'arch/s390/boot/'
 and has a slightly different context.]
Signed-off-by: Frank Heimes <frank.heimes@canonical.com>
---
 arch/s390/boot/vmlinux.lds.S | 12 ++++++++++--
 1 file changed, 11 insertions(+), 2 deletions(-)

diff --git a/arch/s390/boot/compressed/vmlinux.lds.S b/arch/s390/boot/compressed/vmlinux.lds.S
index af5c6860e0a1..fa9d33b01b85 100644
--- a/arch/s390/boot/compressed/vmlinux.lds.S
+++ b/arch/s390/boot/compressed/vmlinux.lds.S
@@ -102,18 +102,27 @@ SECTIONS
 		_compressed_start = .;
 		*(.vmlinux.bin.compressed)
 		_compressed_end = .;
-		FILL(0xff);
-		. = ALIGN(4096);
 	}
 	. = ALIGN(256);
 	.bss : {
 		_bss = . ;
 		*(.bss)
 		*(.bss.*)
 		*(COMMON)
 		. = ALIGN(8);	/* For convenience during zeroing */
 		_ebss = .;
 	}
+
+#define SB_TRAILER_SIZE 32
+	/* Trailer needed for Secure Boot */
+	. += SB_TRAILER_SIZE; /* make sure .sb.trailer does not overwrite the previous section */
+	. = ALIGN(4096) - SB_TRAILER_SIZE;
+	.sb.trailer : {
+		QUAD(0)
+		QUAD(0)
+		QUAD(0)
+		QUAD(0x000000207a49504c)
+	}
 	_end = .;
 
 	/* Sections to be discarded */
-- 
2.25.1

